@@ -77,7 +77,7 @@ class TalismanAPIAdapter:
         self.document_platform_fields = ('id', 'name')
         self.document_account_fields = ('id', 'name')
 
-        self.user_fields = ('id', 'name')
+        self.user_fields = ('id',)
 
         self.concept_fields = (
             'id', 'name', 'notes', 'metric', 'markers', 'system_registration_date', 'system_update_date'
