@@ -207,7 +207,7 @@ class CrawlStateParameters(sgqlc.types.Input):
 
 class CrawlerFilterSettings(sgqlc.types.Input):
     __schema__ = crawlers_api_schema
-    __field_names__ = ('input_value', 'projects', 'crawlers_types', 'last_collection_date', 'creators', 'updaters', 'system_registration_date', 'system_update_date', 'have_active_versions')
+    __field_names__ = ('input_value', 'projects', 'crawlers_types', 'last_collection_date', 'creators', 'updaters', 'system_registration_date', 'system_update_date', 'have_active_versions', 'is_search_crawler')
     input_value = sgqlc.types.Field(String, graphql_name='inputValue')
     projects = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(ID)), graphql_name='projects')
     crawlers_types = sgqlc.types.Field(sgqlc.types.list_of(sgqlc.types.non_null(CrawlersType)), graphql_name='crawlersTypes')
@@ -217,6 +217,7 @@ class CrawlerFilterSettings(sgqlc.types.Input):
     system_registration_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemRegistrationDate')
     system_update_date = sgqlc.types.Field('TimestampInterval', graphql_name='systemUpdateDate')
     have_active_versions = sgqlc.types.Field(Boolean, graphql_name='haveActiveVersions')
+    is_search_crawler = sgqlc.types.Field(Boolean, graphql_name='isSearchCrawler')
 
 
 class CrawlerUpdateInput(sgqlc.types.Input):
