@@ -58,7 +58,7 @@ class ItemState(sgqlc.types.Enum):
 
 class ItemsSort(sgqlc.types.Enum):
     __schema__ = tcontroller_api_schema
-    __choices__ = ('timestamp', 'topic')
+    __choices__ = ('priority', 'timestamp', 'topic')
 
 
 class JSON(sgqlc.types.Scalar):
@@ -74,9 +74,14 @@ class Long(sgqlc.types.Scalar):
     __schema__ = tcontroller_api_schema
 
 
+class MessagePriority(sgqlc.types.Enum):
+    __schema__ = tcontroller_api_schema
+    __choices__ = ('background', 'high', 'normal', 'veryhigh')
+
+
 class MessageSort(sgqlc.types.Enum):
     __schema__ = tcontroller_api_schema
-    __choices__ = ('timestamp',)
+    __choices__ = ('priority', 'timestamp')
 
 
 class PipelineConfigSort(sgqlc.types.Enum):
@@ -482,7 +487,7 @@ class KafkaTopicMetrics(sgqlc.types.Type):
 
 class MessageDuplicate(sgqlc.types.Type):
     __schema__ = tcontroller_api_schema
-    __field_names__ = ('create_time', 'start_time', 'finish_time', 'topic', 'result', 'original_id', 'deleted', 'message')
+    __field_names__ = ('create_time', 'start_time', 'finish_time', 'topic', 'result', 'original_id', 'deleted', 'message', 'priority')
     create_time = sgqlc.types.Field(sgqlc.types.non_null(UnixTime), graphql_name='createTime')
     start_time = sgqlc.types.Field(sgqlc.types.non_null(UnixTime), graphql_name='startTime')
     finish_time = sgqlc.types.Field(sgqlc.types.non_null(UnixTime), graphql_name='finishTime')
@@ -491,6 +496,7 @@ class MessageDuplicate(sgqlc.types.Type):
     original_id = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='originalId')
     deleted = sgqlc.types.Field(sgqlc.types.non_null(Boolean), graphql_name='deleted')
     message = sgqlc.types.Field(sgqlc.types.non_null(JSON), graphql_name='message')
+    priority = sgqlc.types.Field(sgqlc.types.non_null(MessagePriority), graphql_name='priority')
 
 
 class MessageError(sgqlc.types.Type):
@@ -501,7 +507,7 @@ class MessageError(sgqlc.types.Type):
 
 class MessageFailed(sgqlc.types.Type):
     __schema__ = tcontroller_api_schema
-    __field_names__ = ('create_time', 'start_time', 'finish_time', 'topic', 'stage', 'error', 'deleted', 'duplicate_of', 'message')
+    __field_names__ = ('create_time', 'start_time', 'finish_time', 'topic', 'stage', 'error', 'deleted', 'duplicate_of', 'message', 'priority')
     create_time = sgqlc.types.Field(sgqlc.types.non_null(UnixTime), graphql_name='createTime')
     start_time = sgqlc.types.Field(sgqlc.types.non_null(UnixTime), graphql_name='startTime')
     finish_time = sgqlc.types.Field(sgqlc.types.non_null(UnixTime), graphql_name='finishTime')
@@ -511,16 +517,18 @@ class MessageFailed(sgqlc.types.Type):
     deleted = sgqlc.types.Field(sgqlc.types.non_null(Boolean), graphql_name='deleted')
     duplicate_of = sgqlc.types.Field(String, graphql_name='duplicateOf')
     message = sgqlc.types.Field(sgqlc.types.non_null(JSON), graphql_name='message')
+    priority = sgqlc.types.Field(sgqlc.types.non_null(MessagePriority), graphql_name='priority')
 
 
 class MessageInProgress(sgqlc.types.Type):
     __schema__ = tcontroller_api_schema
-    __field_names__ = ('create_time', 'start_time', 'topic', 'stage', 'message')
+    __field_names__ = ('create_time', 'start_time', 'topic', 'stage', 'message', 'priority')
     create_time = sgqlc.types.Field(sgqlc.types.non_null(UnixTime), graphql_name='createTime')
     start_time = sgqlc.types.Field(sgqlc.types.non_null(UnixTime), graphql_name='startTime')
     topic = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='topic')
     stage = sgqlc.types.Field(sgqlc.types.non_null('PipelineTransformSetup'), graphql_name='stage')
     message = sgqlc.types.Field(sgqlc.types.non_null(JSON), graphql_name='message')
+    priority = sgqlc.types.Field(sgqlc.types.non_null(MessagePriority), graphql_name='priority')
 
 
 class MessageList(sgqlc.types.Type):
@@ -541,16 +549,17 @@ class MessageMetrics(sgqlc.types.Type):
 
 class MessageNotHandled(sgqlc.types.Type):
     __schema__ = tcontroller_api_schema
-    __field_names__ = ('create_time', 'topic', 'not_handled', 'message')
+    __field_names__ = ('create_time', 'topic', 'not_handled', 'message', 'priority')
     create_time = sgqlc.types.Field(sgqlc.types.non_null(UnixTime), graphql_name='createTime')
     topic = sgqlc.types.Field(sgqlc.types.non_null(ID), graphql_name='topic')
     not_handled = sgqlc.types.Field(sgqlc.types.non_null(Boolean), graphql_name='notHandled')
     message = sgqlc.types.Field(sgqlc.types.non_null(JSON), graphql_name='message')
+    priority = sgqlc.types.Field(sgqlc.types.non_null(MessagePriority), graphql_name='priority')
 
 
 class MessageOk(sgqlc.types.Type):
     __schema__ = tcontroller_api_schema
-    __field_names__ = ('create_time', 'start_time', 'finish_time', 'topic', 'result', 'deleted', 'message')
+    __field_names__ = ('create_time', 'start_time', 'finish_time', 'topic', 'result', 'deleted', 'message', 'priority')
     create_time = sgqlc.types.Field(sgqlc.types.non_null(UnixTime), graphql_name='createTime')
     start_time = sgqlc.types.Field(sgqlc.types.non_null(UnixTime), graphql_name='startTime')
     finish_time = sgqlc.types.Field(sgqlc.types.non_null(UnixTime), graphql_name='finishTime')
@@ -558,6 +567,7 @@ class MessageOk(sgqlc.types.Type):
     result = sgqlc.types.Field(String, graphql_name='result')
     deleted = sgqlc.types.Field(sgqlc.types.non_null(Boolean), graphql_name='deleted')
     message = sgqlc.types.Field(sgqlc.types.non_null(JSON), graphql_name='message')
+    priority = sgqlc.types.Field(sgqlc.types.non_null(MessagePriority), graphql_name='priority')
 
 
 class MessageStatus(sgqlc.types.Type):
@@ -633,12 +643,14 @@ class Mutation(sgqlc.types.Type):
         ('message_id', sgqlc.types.Arg(sgqlc.types.non_null(ID), graphql_name='messageId', default=None)),
         ('topic', sgqlc.types.Arg(ID, graphql_name='topic', default=None)),
         ('use_kb', sgqlc.types.Arg(Boolean, graphql_name='useKb', default=False)),
+        ('priority', sgqlc.types.Arg(MessagePriority, graphql_name='priority', default='normal')),
 ))
     )
     reprocess_messages = sgqlc.types.Field(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(ID))), graphql_name='reprocessMessages', args=sgqlc.types.ArgDict((
         ('message_ids', sgqlc.types.Arg(sgqlc.types.non_null(sgqlc.types.list_of(sgqlc.types.non_null(ID))), graphql_name='messageIds', default=None)),
         ('topic', sgqlc.types.Arg(ID, graphql_name='topic', default=None)),
         ('use_kb', sgqlc.types.Arg(Boolean, graphql_name='useKb', default=False)),
+        ('priority', sgqlc.types.Arg(MessagePriority, graphql_name='priority', default='normal')),
 ))
     )
     update_exporter = sgqlc.types.Field(sgqlc.types.non_null('Exporter'), graphql_name='updateExporter', args=sgqlc.types.ArgDict((
@@ -1025,12 +1037,13 @@ class RecordInterface(sgqlc.types.Interface):
 
 class ServiceStats(sgqlc.types.Type):
     __schema__ = tcontroller_api_schema
-    __field_names__ = ('name', 'duration', 'load', 'ok_requests', 'failed_requests')
+    __field_names__ = ('name', 'duration', 'load', 'ok_requests', 'failed_requests', 'ok_request_max_duration')
     name = sgqlc.types.Field(sgqlc.types.non_null(String), graphql_name='name')
     duration = sgqlc.types.Field(sgqlc.types.non_null(Float), graphql_name='duration')
     load = sgqlc.types.Field(sgqlc.types.non_null(Float), graphql_name='load')
     ok_requests = sgqlc.types.Field(sgqlc.types.non_null(Int), graphql_name='okRequests')
     failed_requests = sgqlc.types.Field(sgqlc.types.non_null(Int), graphql_name='failedRequests')
+    ok_request_max_duration = sgqlc.types.Field(sgqlc.types.non_null(Float), graphql_name='okRequestMaxDuration')
 
 
 class TaskMetrics(sgqlc.types.Type):
